## What's Changed

### 修复

1. 修复 FishAudio TTS 不可用的问题；
2. 修复 Anthropic API Chat Provider 部分情况下请求报错的问题；
3. 修复部分情况下 WebUI 日志重建连接之后丢失日志的问题；
4. 修复部分情况下 /provider 指令报错 index out of range 的问题；
5. 修复通过 `uv` 或者 cli 方式启动 AstrBot，缺少所有内置插件的问题。

### 优化

1. 丢弃值为 None 的 `tool_call_id` 和 `tool_calls` 字段，提高接口兼容性。

### 新增

1. 支持备份 AstrBot 数据和导入数据功能（Beta）。入口：WebUi -> 设置 -> 备份。
2. text_chat 和 text_chat_stream 接口支持额外用户内容块参数 `extra_user_content_parts`，用于在用户消息后添加额外的内容块（如系统提醒、指令等）。